@@ -80,7 +80,8 @@ class CoordinateType(list):
 				vmax = self[-1][0]
 		return colormath.get_gamma(values, 100.0, vmin, vmax, average, least_squares)
 	
-	def get_transfer_function(self, best=True, slice=(0.05, 0.95)):
+	def get_transfer_function(self, best=True, slice=(0.05, 0.95),
+							  outoffset=None):
 		"""
 		Return transfer function name, exponent and match percentage
 		
@@ -88,66 +89,18 @@ class CoordinateType(list):
 		transfer_function = self._transfer_function.get((best, slice))
 		if transfer_function:
 			return transfer_function
-		trc = ICCP.CurveType()
-		match = {}
-		vmin = self[0][0]
-		vmax = self[-1][0]
-		best_yx = (0, 255)
-		for i, (y, x) in enumerate(self):
-			if x - 127.5 > 0 and x < best_yx[1]:
-				best_yx = (y, x)
-		gamma = colormath.get_gamma([(best_yx[1] / 255.0 * 100.0, best_yx[0])], 100.0, vmin, vmax)
-		for name, exp in (("Rec. 709", -709),
-						  ("Rec. 1886", -1886),
-						  ("SMPTE 240M", -240),
-						  ("SMPTE 2084", -2084),
-						  ("DICOM", -1023),
-						  ("L*", -3.0),
-						  ("sRGB", -2.4),
-						  ("Gamma %.2f" % gamma, gamma)):
-			if name in ("DICOM", "Rec. 1886", "SMPTE 2084"):
-				if self.profile and isinstance(self.profile.tags.get("lumi"),
-											   ICCP.XYZType):
-					white_cdm2 = self.profile.tags.lumi.Y
-				else:
-					white_cdm2 = 100.0
-				black_Y = vmin / 100.0
-				black_cdm2 = black_Y * white_cdm2
-				try:
-					if name == "DICOM":
-						trc.set_dicom_trc(black_cdm2, white_cdm2, size=len(self))
-					elif name == "Rec. 1886":
-						trc.set_bt1886_trc(black_Y, size=len(self))
-					elif name == "SMPTE 2084":
-						trc.set_smpte2084_trc(black_cdm2, white_cdm2, size=len(self))
-				except ValueError:
-					continue
-			else:
-				trc.set_trc(exp, len(self), vmin * 655.35, vmax * 655.35)
-			match[(name, exp)] = 0.0
-			count = 0
-			start = slice[0] * 255
-			end = slice[1] * 255
-			for i, (n, x) in enumerate(self):
-				##n = colormath.XYZ2Lab(0, n, 0)[0]
-				if x >= start and x <= end:
-					n = colormath.get_gamma([(x / 255.0 * 100, n)], 100.0, vmin, vmax, False)
-					if n:
-						n = n[0]
-						##n2 = colormath.XYZ2Lab(0, trc[i][0], 0)[0]
-						n2 = colormath.get_gamma([(i / (len(trc) - 1.0) * 65535, trc[i])], 65535, vmin * 655.35, vmax * 655.35, False)
-						if n2 and n2[0]:
-							n2 = n2[0]
-							match[(name, exp)] += 1 - (max(n, n2) - min(n, n2)) / n2
-							count += 1
-			if count:
-				match[(name, exp)] /= count
-		if not best:
-			self._transfer_function[(best, slice)] = match
-			return match
-		match, (name, exp) = sorted(zip(match.values(), match.keys()))[-1]
-		self._transfer_function[(best, slice)] = (name, exp), match
-		return (name, exp), match
+		xp = []
+		fp = []
+		for y, x in self:
+			xp.append(x)
+			fp.append(y)
+		interp = colormath.Interp(xp, fp, use_numpy=True)
+		otrc = ICCP.CurveType(profile=self.profile)
+		for i in xrange(len(self)):
+			otrc.append(interp(i / (len(self) - 1.0) * 255) / 100 * 65535)
+		match = otrc.get_transfer_function(best, slice, outoffset=outoffset)
+		self._transfer_function[(best, slice)] = match
+		return match
 	
 	def set_trc(self, power=2.2, values=(), vmin=0, vmax=100):
 		"""
@@ -1268,7 +1221,8 @@ class LUTFrame(BaseFrame):
 		try:
 			odata = self.worker.xicclu(profile, idata, intent,
 									   direction, order, pcs,
-									   use_icclu=use_icclu)
+									   use_icclu=use_icclu,
+									   get_clip=direction == "if")
 		except Exception, exception:
 			self.client.errors.append(Error(safe_unicode(exception)))
 		
@@ -1276,6 +1230,28 @@ class LUTFrame(BaseFrame):
 			return
 
 		if direction in ("b", "if") or profile.connectionColorSpace == "RGB":
+			if direction == "if":
+				Lbp = self.worker.xicclu(profile, [[0, 0, 0]], intent, "f",
+										 order, "l", use_icclu=use_icclu)[0][0]
+				maxval = size - 1.0
+
+				# Deal with values that got clipped (below black as well as white)
+				do_low_clip = True
+				for i, values in enumerate(odata):
+					if values[3] is True:
+						if do_low_clip and i / maxval * 100 < Lbp:
+							# Set to black
+							values[:] = [0.0, 0.0, 0.0]
+						elif (i == maxval and
+							  [round(v, 4) for v in values[:3]] == [1, 1, 1]):
+							# Set to white
+							values[:] = [1.0, 1.0, 1.0]
+					else:
+						# First non-clipping value disables low clipping
+						do_low_clip = False
+					if len(values) > 3:
+						values.pop()
+
 			RGB_triplets = odata
 		else:
 			Lab_triplets = odata
@@ -1530,7 +1506,8 @@ class LUTFrame(BaseFrame):
 										  self.tf_gTRC[i][1] +
 										  self.tf_bTRC[i][1]) / 3.0])
 			if getattr(self, "trc", None):
-				transfer_function = self.trc.get_transfer_function(slice=(0.00, 1.00))
+				transfer_function = self.trc.get_transfer_function(slice=(0.00, 1.00),
+																   outoffset=1.0)
 			#if "R" in colorants and "G" in colorants and "B" in colorants:
 				#if self.profile.tags.rTRC == self.profile.tags.gTRC == self.profile.tags.bTRC:
 					#transfer_function = self.profile.tags.rTRC.get_transfer_function()
@@ -1705,7 +1682,10 @@ class LUTFrame(BaseFrame):
 		if self.worker.tempdir and os.path.isdir(self.worker.tempdir):
 			self.worker.wrapup(False)
 		config.writecfg(module="curve-viewer", options=("display.number", ))
-		event.Skip()
+		# Hide first (looks nicer)
+		self.Hide()
+		# Need to use CallAfter to prevent hang under Windows if minimized
+		wx.CallAfter(self.Destroy)
 
 	def OnMotion(self, event):
 		if isinstance(event, wx.MouseEvent):
@@ -1909,7 +1889,7 @@ class LUTFrame(BaseFrame):
 													 (("R", R), ("G", G), ("B", B)))])
 						# Note: We need to make sure each point is a float because it
 						# might be a decimal.Decimal, which can't be divided by floats!
-						gamma.append(label + " %.2f" % (math.log(float(y) / axis_y) / math.log(x / 255.0)))
+						gamma.append(label + " %.2f" % round(math.log(float(y) / axis_y) / math.log(x / 255.0), 2))
 						if "=" in label:
 							break
 					if gamma:
