@@ -30,7 +30,7 @@ from wxwindows import (BaseApp, BaseFrame, BitmapBackgroundPanelText,
 					   CustomCheckBox, CustomGrid, CustomRowLabelRenderer,
 					   ConfirmDialog, FileDrop, InfoDialog, SimpleBook,
 					   TwoWaySplitter)
-from wxfixes import GenBitmapButton as BitmapButton
+from wxfixes import GenBitmapButton as BitmapButton, wx_Panel
 import colormath
 import config
 import wxenhancedplot as plot
@@ -284,7 +284,7 @@ class GamutCanvas(LUTCanvas):
 			min_x = -65.0
 			min_y = -65.0
 			step = 25
-		elif self.colorspace == "CtCp":
+		elif self.colorspace == "ICtCp":
 			label_x = "Ct"
 			label_y = "Cp"
 			max_x = 0.4
@@ -292,9 +292,21 @@ class GamutCanvas(LUTCanvas):
 			min_x = -0.5
 			min_y = -0.4
 			step = .1
+		elif self.colorspace == "IPT":
+			label_x = "P"
+			label_y = "T"
+			max_x = 1.0
+			max_y = 1.0
+			min_x = -1.0
+			min_y = -1.0
+			step = .25
 		else:
-			label_x = "a*"
-			label_y = "b*"
+			if self.colorspace == "Lpt":
+				label_x = "p"
+				label_y = "t"
+			else:
+				label_x = "a*"
+				label_y = "b*"
 			max_x = 150.0
 			max_y = 150.0
 			min_x = -150.0
@@ -309,8 +321,10 @@ class GamutCanvas(LUTCanvas):
 						  "DIN99b": lambda X, Y, Z: colormath.XYZ2DIN99b(*[v * 100 for v in X, Y, Z])[1:],
 						  "DIN99c": lambda X, Y, Z: colormath.XYZ2DIN99c(*[v * 100 for v in X, Y, Z])[1:],
 						  "DIN99d": lambda X, Y, Z: colormath.XYZ2DIN99d(*[v * 100 for v in X, Y, Z])[1:],
-						  "CtCp": lambda X, Y, Z: colormath.XYZ2ICtCp(X, Y, Z,
-																	  clamp=False)[1:]}[self.colorspace]
+						  "ICtCp": lambda X, Y, Z: colormath.XYZ2ICtCp(X, Y, Z,
+																	  clamp=False)[1:],
+						  "IPT": lambda X, Y, Z: colormath.XYZ2IPT(X, Y, Z)[1:],
+						  "Lpt": lambda X, Y, Z: colormath.XYZ2Lpt(*[v * 100 for v in X, Y, Z])[1:]}[self.colorspace]
 
 		if show_outline and (self.colorspace == "a*b*" or
 							 self.colorspace.startswith("DIN99")):
@@ -642,17 +656,18 @@ class GamutCanvas(LUTCanvas):
 		self.order = order
 
 
-class GamutViewOptions(wx.Panel):
+class GamutViewOptions(wx_Panel):
 	
 	def __init__(self, *args, **kwargs):
 		scale = getcfg("app.dpi") / config.get_default_dpi()
 		if scale < 1:
 			scale = 1
 
-		wx.Panel.__init__(self, *args, **kwargs)
+		wx_Panel.__init__(self, *args, **kwargs)
 		self.SetBackgroundColour(BGCOLOUR)
 		self.sizer = wx.FlexGridSizer(0, 3, 4, 0)
 		self.sizer.AddGrowableCol(0)
+		self.sizer.AddGrowableCol(1)
 		self.sizer.AddGrowableCol(2)
 		self.SetSizer(self.sizer)
 
@@ -695,7 +710,8 @@ class GamutViewOptions(wx.Panel):
 		
 		self.sizer.Add((0, 0))
 		self.options_sizer = wx.FlexGridSizer(0, 3, 4, 8)
-		self.sizer.Add(self.options_sizer)
+		self.options_sizer.AddGrowableCol(2)
+		self.sizer.Add(self.options_sizer, flag=wx.EXPAND)
 		
 		# Colorspace select
 		self.colorspace_outline_bmp = wx.StaticBitmap(self, -1,
@@ -718,9 +734,11 @@ class GamutViewOptions(wx.Panel):
 														  "DIN99b",
 														  "DIN99c",
 														  "DIN99d",
-														  "CtCp"])
+														  "ICtCp",
+														  "IPT",
+														  "Lpt"])
 		self.options_sizer.Add(self.colorspace_select, 
-							   flag=wx.ALIGN_CENTER_VERTICAL)
+							   flag=wx.ALIGN_CENTER_VERTICAL | wx.EXPAND)
 		self.colorspace_select.Bind(wx.EVT_CHOICE, self.generic_select_handler)
 		self.colorspace_select.SetSelection(0)
 		
@@ -755,7 +773,7 @@ class GamutViewOptions(wx.Panel):
 														  lang.getstr("whitepoint.colortemp.locus.daylight"),
 														  lang.getstr("whitepoint.colortemp.locus.blackbody")])
 		self.options_sizer.Add(self.whitepoint_select, 
-							   flag=wx.ALIGN_CENTER_VERTICAL)
+							   flag=wx.ALIGN_CENTER_VERTICAL | wx.EXPAND)
 		self.whitepoint_select.Bind(wx.EVT_CHOICE, self.generic_select_handler)
 		self.whitepoint_select.SetSelection(0)
 		self.whitepoint_bmp.Hide()
@@ -791,7 +809,7 @@ class GamutViewOptions(wx.Panel):
 												   choices=[])
 		self.comparison_profiles_sort()
 		self.options_sizer.Add(self.comparison_profile_select, 
-							   flag=wx.ALIGN_CENTER_VERTICAL)
+							   flag=wx.ALIGN_CENTER_VERTICAL | wx.EXPAND)
 		self.comparison_profile_select.Bind(wx.EVT_CHOICE,
 											self.comparison_profile_select_handler)
 		droptarget = FileDrop(self.TopLevelParent,
@@ -817,7 +835,7 @@ class GamutViewOptions(wx.Panel):
 														  lang.getstr("gamap.intents.p"),
 														  lang.getstr("gamap.intents.s")])
 		self.options_sizer.Add(self.rendering_intent_select, 
-							   flag=wx.ALIGN_CENTER_VERTICAL)
+							   flag=wx.ALIGN_CENTER_VERTICAL | wx.EXPAND)
 		self.rendering_intent_select.Bind(wx.EVT_CHOICE,
 										  self.rendering_intent_select_handler)
 		self.rendering_intent_select.SetSelection(0)
@@ -838,10 +856,9 @@ class GamutViewOptions(wx.Panel):
 										  choices=[lang.getstr("direction.forward"),
 												   lang.getstr("direction.backward.inverted")])
 		self.options_sizer.Add(self.direction_select,
-							   flag=wx.ALIGN_CENTER_VERTICAL)
+							   flag=wx.ALIGN_CENTER_VERTICAL | wx.EXPAND)
 		self.direction_select.Bind(wx.EVT_CHOICE, self.direction_select_handler)
 		self.direction_select.SetSelection(0)
-		self.direction_select.Hide()
 
 		self.sizer.Add((0, 0))
 
@@ -943,9 +960,10 @@ class GamutViewOptions(wx.Panel):
 				5: "DIN99b",
 				6: "DIN99c",
 				7: "DIN99d",
-				8: "CtCp" if dimensions == 2 else "ICtCp"}.get(
-								  self.colorspace_select.GetSelection(),
-								 "a*b*" if dimensions == 2 else "Lab")
+				8: "ICtCp",
+				9: "IPT",
+				10: "Lpt"}.get(self.colorspace_select.GetSelection(),
+							   "a*b*" if dimensions == 2 else "Lab")
 
 	@property
 	def intent(self):
@@ -972,7 +990,7 @@ class GamutViewOptions(wx.Panel):
 	def toggle_clut_handler(self, event):
 		parent = self.TopLevelParent
 		self.Freeze()
-		self.direction_select.Show(bool(parent.profile) and 
+		self.direction_select.Enable(bool(parent.profile) and 
 								   "B2A0" in parent.profile.tags and
 								   "A2B0" in parent.profile.tags and
 								   self.toggle_clut.GetValue())
@@ -1004,7 +1022,7 @@ class ProfileInfoFrame(LUTFrame):
 		self.splitter = TwoWaySplitter(self, -1, agwStyle = wx.SP_LIVE_UPDATE | wx.SP_NOSASH)
 		self.sizer.Add(self.splitter, 1, flag=wx.EXPAND)
 		
-		p1 = wx.Panel(self.splitter, name="canvaspanel")
+		p1 = wx_Panel(self.splitter, name="canvaspanel")
 		p1.SetBackgroundColour(BGCOLOUR)
 		p1.sizer = wx.BoxSizer(wx.VERTICAL)
 		p1.SetSizer(p1.sizer)
@@ -1092,7 +1110,7 @@ class ProfileInfoFrame(LUTFrame):
 		self.options_panel.AddPage(self.gamut_view_options, "")
 		
 		# Curve view options
-		self.lut_view_options = wx.Panel(p1, name="lut_view_options")
+		self.lut_view_options = wx_Panel(p1, name="lut_view_options")
 		self.lut_view_options.SetBackgroundColour(BGCOLOUR)
 		self.lut_view_options_sizer = self.box_sizer = wx.FlexGridSizer(0, 3, 4, 4)
 		self.lut_view_options_sizer.AddGrowableCol(0)
@@ -1176,7 +1194,7 @@ class ProfileInfoFrame(LUTFrame):
 		
 		self.lut_view_options_sizer.Add((0, 0))
 		
-		p2 = wx.Panel(self.splitter, name="gridpanel")
+		p2 = wx_Panel(self.splitter, name="gridpanel")
 		p2.sizer = wx.BoxSizer(wx.VERTICAL)
 		p2.SetSizer(p2.sizer)
 		self.splitter.AppendWindow(p2)
@@ -1315,10 +1333,12 @@ class ProfileInfoFrame(LUTFrame):
 													profile.tags.get("kTRC"))
 		self.trc = None
 		
-		self.gamut_view_options.direction_select.Show("B2A0" in
-													  self.profile.tags and
-													  "A2B0" in
-													  self.profile.tags)
+		self.gamut_view_options.direction_select.Enable("B2A0" in
+													    self.profile.tags and
+													    "A2B0" in
+													    self.profile.tags)
+		if not self.gamut_view_options.direction_select.Enabled:
+			self.gamut_view_options.direction_select.SetSelection(0)
 		self.gamut_view_options.toggle_clut.SetValue("B2A0" in profile.tags or
 													 "A2B0" in profile.tags)
 		self.gamut_view_options.toggle_clut.Show("B2A0" in profile.tags or
@@ -1463,7 +1483,10 @@ class ProfileInfoFrame(LUTFrame):
 												 "last_icc_path",
 												 "position.profile_info",
 												 "size.profile_info"))
-		event.Skip()
+		# Hide first (looks nicer)
+		self.Hide()
+		# Need to use CallAfter to prevent hang under Windows if minimized
+		wx.CallAfter(self.Destroy)
 
 	def OnMotion(self, event):
 		if isinstance(event, wx.MouseEvent):
@@ -1510,9 +1533,15 @@ class ProfileInfoFrame(LUTFrame):
 						# DIN99
 						a, b = colormath.DIN992Lab(L99, xy[0], xy[1])[1:]
 					x, y = colormath.Lab2xyY(100.0, a, b)[:2]
-				elif page.colorspace == "CtCp":
+				elif page.colorspace == "ICtCp":
 					X, Y, Z = colormath.ICtCp2XYZ(1.0, xy[0], xy[1])
 					x, y = colormath.XYZ2xyY(X, Y, Z)[:2]
+				elif page.colorspace == "IPT":
+					X, Y, Z = colormath.IPT2XYZ(1.0, xy[0], xy[1])
+					x, y = colormath.XYZ2xyY(X, Y, Z)[:2]
+				elif page.colorspace == "Lpt":
+					X, Y, Z = colormath.Lpt2XYZ(100.0, xy[0], xy[1])
+					x, y = colormath.XYZ2xyY(X, Y, Z)[:2]
 				else:
 					# xy
 					x, y = xy
